Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/h3lis200dl_simpletest.py
    :caption: examples/h3lis200dl_simpletest.py
    :lines: 5-

Operation mode settings
------------------------

Example showing the Operation mode setting

.. literalinclude:: ../examples/h3lis200dl_operation_mode.py
    :caption: examples/h3lis200dl_operation_mode.py
    :lines: 5-

Full scale selection settings
-----------------------------

Example showing the Full scale selection setting

.. literalinclude:: ../examples/h3lis200dl_full_scale_selection.py
    :caption: examples/h3lis200dl_full_scale_selection.py
    :lines: 5-

Data rate settings
-------------------

Example showing the Data rate setting

.. literalinclude:: ../examples/h3lis200dl_data_rate.py
    :caption: examples/h3lis200dl_data_rate.py
    :lines: 5-

High pass filter cutoff settings
---------------------------------

Example showing the High pass filter cutoff setting

.. literalinclude:: ../examples/h3lis200dl_high_pass_filter_cutoff.py
    :caption: examples/h3lis200dl_high_pass_filter_cutoff.py
    :lines: 5-

Interrupt Example
---------------------------------

Interrupt Example

.. literalinclude:: ../examples/h3lis200dl_interrupt_example.py
    :caption: examples/h3lis200dl_interrupt_example.py
    :lines: 5-
